==> torch-points-kernels-0.5.2.tar.gz: torch-points-kernels-0.5.2/cuda/include/utils.h <==
#pragma once
#include <ATen/cuda/CUDAContext.h>
#include <torch/extension.h>

#define CHECK_CUDA(x)                                                                              \
    do                                                                                             \
    {                                                                                              \
        TORCH_CHECK(x.type().is_cuda(), #x " must be a CUDA tensor");                              \
    } while (0)

#define CHECK_CONTIGUOUS(x)                                                                        \
    do                                                                                             \
    {                                                                                              \
        TORCH_CHECK(x.is_contiguous(), #x " must be a contiguous tensor");                         \
    } while (0)

#define CHECK_IS_INT(x)                                                                            \
    do                                                                                             \
    {                                                                                              \
        TORCH_CHECK(x.scalar_type() == at::ScalarType::Int, #x " must be an int tensor");          \
    } while (0)

#define CHECK_IS_FLOAT(x)                                                                          \
    do                                                                                             \
    {                                                                                              \
        TORCH_CHECK(x.scalar_type() == at::ScalarType::Float, #x " must be a float tensor");       \
    } while (0)

==> torch-points-kernels-0.7.0.tar.gz: torch-points-kernels-0.7.0/cuda/include/utils.h <==
#pragma once
#include <ATen/cuda/CUDAContext.h>
#include <torch/extension.h>

#define CHECK_CUDA(x)                                                                              \
    do                                                                                             \
    {                                                                                              \
        TORCH_CHECK(x.is_cuda(), #x " must be a CUDA tensor");                                     \
    } while (0)

#define CHECK_CONTIGUOUS(x)                                                                        \
    do                                                                                             \
    {                                                                                              \
        TORCH_CHECK(x.is_contiguous(), #x " must be a contiguous tensor");                         \
    } while (0)

#define CHECK_IS_INT(x)                                                                            \
    do                                                                                             \
    {                                                                                              \
        TORCH_CHECK(x.scalar_type() == at::ScalarType::Int, #x " must be an int tensor");          \
    } while (0)

#define CHECK_IS_FLOAT(x)                                                                          \
    do                                                                                             \
    {                                                                                              \
        TORCH_CHECK(x.scalar_type() == at::ScalarType::Float, #x " must be a float tensor");       \
    } while (0)
